@@ -8,14 +8,14 @@
 namespace stan {
   namespace lang {
 
-    simplex_var_decl::simplex_var_decl() : base_var_decl(VECTOR_T) { }
+    simplex_var_decl::simplex_var_decl() : base_var_decl(vector_type()) { }
 
     simplex_var_decl::simplex_var_decl(const expression& K,
                                        const std::string& name,
                                        const std::vector<expression>& dims,
                                        const expression& def)
 
-      : base_var_decl(name, dims, VECTOR_T, def),  K_(K) { }
+      : base_var_decl(name, dims, vector_type(), def),  K_(K) { }
 
   }
 }
